% Boilerplote for Typesetting the incipit
% Arguments : music clef
incBoiler =
#(define-music-function
     (parser location inc-music inc-clef inc-time)
     (ly:music? ly:music? ly:music?)
   #{
<<
  \new MensuralVoice <<
    %\repeat unfold 9 { s1 \noBreak }
    {
      \set Score.timing = ##f
      $inc-clef
      $inc-time
      \override NoteHead.style = #'petrucci
      \override Rest.style = #'mensural
      \override Staff.TimeSignature.style = #'mensural
      $inc-music
      s\breve
    }
  >>
>>
#})

% Boilerplate for Typesetting Music in Modern Staff
% Arguments : music clef
musBoiler =
#(define-music-function
     (parser location sub-music sub-clef sub-time)
     (ly:music? ly:music? ly:music?)
   #{
  \override NoteHead.style = #'baroque
  $sub-clef
  $sub-time
  \expandFullBarRests
  \accidentalStyle forget
  $sub-music
  \override Staff.BarLine #'transparent =##f
  \bar "|." 
#}
)

%Function to typeset incipit properly
%%%%%%%%%%%%%%%%%%%%%%%%
incipit =
#(define-music-function (parser location incipit-music) (ly:music?)
  #{
  \once \override Staff.InstrumentName.self-alignment-X = #RIGHT
  \once \override Staff.InstrumentName.self-alignment-Y = ##f
  \once \override Staff.InstrumentName.padding = #0.3
  \once \override Staff.InstrumentName.stencil =
  #(lambda (grob)
    (let* ((instrument-name (ly:grob-property grob 'long-text)))
     (set! (ly:grob-property grob 'long-text)
      #{ \markup
      \score
      {
      { \new MensuralStaff \with {
      \once \override Staff.InstrumentName.self-alignment-X = #CENTER
      \once \override Staff.InstrumentName.self-alignment-Y = #-0.7
      instrumentName = \markup {
      \center-column {
      \with-color #white "___________"
      #instrument-name
      }
      }
    } $incipit-music
    }
      \layout { $(ly:grob-layout grob)
      line-width = \indent
      indent =
				% primitive-eval is probably easiest for
				% escaping lexical closure and evaluating
				% everything respective to (current-module).
      #(primitive-eval
	'(or (false-if-exception (- indent incipit-width))
	  (* 0.5 indent)))
		ragged-right = ##f
		ragged-last = ##f
		system-count = #1 }
    }
	 #})
  (system-start-text::print grob)))
  #})

%Function to pad lyrics by Mats Bengtsson in the Lilypond-user mailing list

% Copied from scm/stencil.scm in version 2.11
#(define-public (stencil-with-color stencil color)
 (ly:make-stencil
  (list 'color color (ly:stencil-expr stencil))
  (ly:stencil-extent stencil X)
  (ly:stencil-extent stencil Y)))

% Copied from scm/stencil.scm in version 2.11
% Extended to add some padding around:
#(define (stencil-padded-whiteout stencil padding)
 (let*
     ((x-ext (ly:stencil-extent stencil X))
      (y-ext (ly:stencil-extent stencil Y))

      )

   (ly:stencil-add
    (stencil-with-color (ly:round-filled-box
             (interval-widen x-ext padding)
             (interval-widen y-ext padding) 0.0)
                        white)
    stencil)
   ))

#(define (text-in-white-box grob)
  (stencil-padded-whiteout (ly:text-interface::print grob) 0.5))

%Function to repeat rhythms on different pitches
%Taken from http://lsr.di.unimi.it/LSR/Item?id=346
defineTransform =
#(define-scheme-function (parser location pattern)
   (ly:music?)
   (define-music-function (parser location pitchseq)
     (ly:music?)
     (let ((pitches (list->vector
                     (reverse!
                      (fold-some-music
                       (lambda (m)
                         (ly:pitch? (ly:music-property m 'pitch)))
                       (lambda (m l)
                         (cons (ly:music-property m 'pitch) l))
                       '()
                       pitchseq))))
           (m (ly:music-deep-copy pattern)))
       (for-some-music
        (lambda (m)
          (let ((p (ly:music-property m 'pitch)))
            (and (ly:pitch? p)
                 (begin
                   (set! (ly:music-property m 'pitch)
                         (vector-ref pitches
                                     (ly:pitch-steps p)))
                   #t))))
        m)
       m)))

%%%%%%%%%%%%%%%%%%%%%%%%%

flex = {
    \override NoteHead.flexa-width = #4
    \override NoteHead.ligature-flexa = ##t
}

flexe = {
  \revert NoteHead.ligature-flexa
}

petrbl = {}

petrble = {}
% More definitions and typesetting settings
rn = { 
  \once \override NoteHead.color = #red
  \once \override Dots.color = #red
}

% Function for editorial accidentals
fic = { \once \set suggestAccidentals = ##t }
it=\override LyricText.font-shape = #'italic
ite=\override LyricText.font-shape = #'upright

%Remove barlines inside staves
global = {
  \set Score.skipBars = ##t
  %\set Timing.defaultBarType = "'"
  \override Staff.BarLine #'transparent = ##t
%  \override Staff.LigatureBracket #'transparent = ##t
  \set Staff.midiInstrument = #"electric piano 1"
}

%Shorthand for starting and ending melismas
m = \melisma
me = \melismaEnd

%Glyphs for typesetting incipits with diminuted forms of time signatures
noTS = {
\override Staff.TimeSignature.color = #white
\override Staff.TimeSignature.layer = #-1
}

%The simple proportion of minor prolation mensural signs
OThree =
  \markup{
    \combine
    \musicglyph #"timesig.mensural32"
    \translate #'(1.7 . -0.8) 3
  }

OThreeAlt =
  \markup{
    \combine
    \translate #'(0 . 1.5 )\musicglyph #"timesig.mensural32"
    \translate #'(0.2 . -1) 3
  }

CThree =
  \markup{
    \combine
    \musicglyph #"timesig.mensural44"
    \translate #'(1.7 . -0.8) 3
  }

CutCThree =
  \markup{
    \combine
    \musicglyph #"timesig.mensural22"
    \translate #'(1.7 . -0.8) 3
  }

CTwo =
  \markup{
    \combine
    \musicglyph #"timesig.mensural44"
    \translate #'(1.7 . -0.8) 2
  }

OTwo =
  \markup{
    \combine
    \musicglyph #"timesig.mensural32"
    \translate #'(1.7 . -0.8) 2
  }

%Pick Time Signature stencil (Put this with the music)
TimeSigStencil = {
  \once \override Staff.TimeSignature.stencil = #ly:text-interface::print
  \once \override Staff.TimeSignature.text = \OThree
  }

%Scales for modal transpositions
diatonicScale = {
  c d e f g a b
  }





%%%% Perfected notes converted to modern notation with dots
%%%% Also to facillitate typesetting of full bar rests

%%% Minor Prolation

%%% Closed circle (Tempus Perfectum, Minor Prolatio)
OSemibreveA = #(ly:make-duration -1 0 1/1) %Altered semibreve

OBreve = #(ly:make-duration -1 1 1/1)

OLongaP = #(ly:make-duration -3 0 9/8) %Modus Perfectus,1 L = 3 B = 9 S = 18M

OLongaI = #(ly:make-duration -2 1 1/1) %Modus Perfectus,1 L = 2 B = 6 S = 12M

OBRest = R\breve. %B rest in O mensuration

OThreeBRest = R\breve.*3 %L Rest that takes three ledger spaces

OTwoBRest = R\breve.*2 %L Rest that takes two ledger spaces

%%% Open Circle (Tempus Imperfectum, Minor Prolatio)

CLongaP = #(ly:make-duration -3 1 1/1) %Modus Perfectus,1L = 3B = 6S

CBRest = R\breve

CTwoBRest = R\breve*2 

CThreeBRest = R\breve*3

%%% Major Prolation

SemibreveP = #(ly:make-duration 0 1 1/1)

SRestP = R1. %S rest in major prolation

%%% Closed circle with dot (Tempus Perfectum, Major Prolatio)

ODBreve = #(ly:make-duration -1 0 9/4) %TP, Major Prolation 1 B = 3 S = 9 M

ODBRest = R1.*3 %S rest in O dot mensuration

%%% Open circle with dot (Tempus Imperfectum, Major Prolatio)

CDBreve = #(ly:make-duration -1 1 1/1) %TP, Major Prolation 1 B = 2 S = 6 M

CDBRest = R1.*2

%%% Miscellaneous

%%% Scribal short hand for dotted SB followed by M

sbblack = #(ly:make-duration 1 1 1/1) %Blackened S, always followed by blackened M

mblack = #(ly:make-duration 2 0 1/1) %Blackened M which follows S

SBdottedM = \defineTransform {c'2. d'4}

longaTPMP = #(ly:make-duration -2 0 5/4)





%Linebreak for orginial notation, disregarded in modern transcription
newLine = {}

%Layout for polyphony
  layoutOne =    \layout {
%%%    line-width=19.1 \cm
%%%    interscoreline= 0.0 \cm
%%%    interscorelinefill= 1.0
%%%    textheight= 26.7 \cm
    \context {
      \Lyrics
      \override LyricText #'font-size = #2
    }
    \context {
      \Score
      \hide BarLine
      \override BarNumber #'padding = #2
    }
    \context {
      \Lyrics
%%%    \consists "Bar_engraver"
%%%    \consists "Separating_line_group_engraver"
%%%    \override LyricHyphen #'stencil = #text-in-white-box
    }
    \context {
      \Voice
      \hide Slur
      \remove "Forbid_line_break_engraver"
      \remove "Rest_engraver"
      \consists "Completion_rest_engraver"
    }
    indent = 6\cm
    incipit-width = 4\cm
  }